==> dbus-glib-0.88-i486-66.1.txz: usr/src/dbus-glib-0.88/build-dbus-glib.sh <==
#!/bin/bash
#
# source: http://dbus.freedesktop.org/releases/dbus-glib/dbus-glib-0.88.tar.gz
#
# maintainer: gmg (g.monpontetd@gmail.com)
#

#------------------Set Some Variables

soft='dbus-glib'
softversion='0.88'
packageversion='66.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --enable-static=no

make -j4
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/man?/*.?

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS ChangeLog COPYING HACKING INSTALL NEWS README \
  $dest/usr/doc/$soft-$softversion
( cd $dest/usr/doc/$soft-$softversion
  ln -s ../../share/gtk-doc/html/dbus-glib/ html
)

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

         |-----handy-ruler----------------------------------------------------|
dbus-glib: dbus-glib - is GLib bindings for DBUS
dbus-glib:
dbus-glib: This package includes the glib bindings for the dbus IPC library.
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5

==> dbus-glib-0.98-i486-72.1.txz: usr/src/dbus-glib-0.98/build-dbus-glib.sh <==
#!/bin/bash
#
# source: http://dbus.freedesktop.org/releases/dbus-glib/dbus-glib-0.98.tar.gz
#
# maintainer: gmg (g.monpontetd@gmail.com)
#

#------------------Set Some Variables

soft='dbus-glib'
softversion='0.98'
packageversion='72.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --mandir=/usr/man \
  --enable-static=no \
  --with-html-dir=/usr/doc/$soft-$softversion

make -j6
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

gzip -9 $dest/usr/man/man?/*.?

#-------------------Prepare the documentation

cp -a \
  AUTHORS ChangeLog COPYING HACKING INSTALL NEWS README \
  $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

         |-----handy-ruler----------------------------------------------------|
dbus-glib: dbus-glib - is GLib bindings for DBUS
dbus-glib:
dbus-glib: This package includes the glib bindings for the dbus IPC library.
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
dbus-glib:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5
